@@ -70,6 +70,19 @@ class SerializationInfo(Protocol):
         ...
 
 
+class ValidationInfo(Protocol):
+    """
+    Argument passed to validation functions.
+    """
+
+    data: Dict[str, Any]
+    """All of the fields and data being validated for this model."""
+    context: Dict[str, Any]
+    """Current validation context."""
+    config: CoreConfig | None
+    """The CoreConfig that applies to this validation."""
+
+
 ExpectedSerializationTypes = Literal[
     'none',
     'int',
@@ -1430,9 +1443,7 @@ def dict_schema(
 
 
 class ValidatorFunction(Protocol):
-    def __call__(
-        self, __input_value: Any, *, data: Any, config: CoreConfig | None, context: Any, **future_kwargs: Any
-    ) -> Any:  # pragma: no cover
+    def __call__(self, __input_value: Any, __info: ValidationInfo) -> Any:  # pragma: no cover
         ...
 
 
@@ -1461,7 +1472,7 @@ def function_before_schema(
     from typing import Any
     from pydantic_core import SchemaValidator, core_schema
 
-    def fn(v: Any, **kwargs) -> str:
+    def fn(v: Any, info: core_schema.ValidationInfo) -> str:
         v_str = str(v)
         assert 'hello' in v_str
         return v_str + 'world'
@@ -1503,7 +1514,7 @@ def function_after_schema(
     ```py
     from pydantic_core import SchemaValidator, core_schema
 
-    def fn(v: str, **kwargs) -> str:
+    def fn(v: str, info: core_schema.ValidationInfo) -> str:
         assert 'hello' in v
         return v + 'world'
 
@@ -1537,14 +1548,7 @@ class CallableValidator(Protocol):
 
 class WrapValidatorFunction(Protocol):
     def __call__(
-        self,
-        __input_value: Any,
-        *,
-        validator: CallableValidator,
-        data: Any,
-        config: CoreConfig | None,
-        context: Any,
-        **future_kwargs: Any,
+        self, __input_value: Any, __validator: CallableValidator, __info: ValidationInfo
     ) -> Any:  # pragma: no cover
         ...
 
@@ -1575,7 +1579,7 @@ def function_wrap_schema(
     ```py
     from pydantic_core import SchemaValidator, core_schema
 
-    def fn(v: str, *, validator, **kwargs) -> str:
+    def fn(v: str, validator: core_schema.CallableValidator, info: core_schema.ValidationInfo) -> str:
         return validator(input_value=v) + 'world'
 
     schema = core_schema.function_wrap_schema(function=fn, schema=core_schema.str_schema())
@@ -1619,7 +1623,7 @@ def function_plain_schema(
     ```py
     from pydantic_core import SchemaValidator, core_schema
 
-    def fn(v: str, **kwargs) -> str:
+    def fn(v: str, info: core_schema.ValidationInfo) -> str:
         assert 'hello' in v
         return v + 'world'
 
@@ -1912,7 +1916,7 @@ def chain_schema(
     ```py
     from pydantic_core import SchemaValidator, core_schema
 
-    def fn(v: str, **kwargs) -> str:
+    def fn(v: str, info: core_schema.ValidationInfo) -> str:
         assert 'hello' in v
         return v + ' world'
 
@@ -1956,7 +1960,7 @@ def lax_or_strict_schema(
     ```py
     from pydantic_core import SchemaValidator, core_schema
 
-    def fn(v: str, **kwargs) -> str:
+    def fn(v: str, info: core_schema.ValidationInfo) -> str:
         assert 'hello' in v
         return v + ' world'
 
