@@ -17,7 +17,7 @@ impl BuildValidator for AnyValidator {
     fn build(
         _schema: &PyDict,
         _config: Option<&PyDict>,
-        _build_context: &mut BuildContext,
+        _build_context: &mut BuildContext<CombinedValidator>,
     ) -> PyResult<CombinedValidator> {
         Ok(Self.into())
     }
