@@ -35,7 +35,7 @@ impl BuildValidator for ArgumentsValidator {
     fn build(
         schema: &PyDict,
         config: Option<&PyDict>,
-        build_context: &mut BuildContext,
+        build_context: &mut BuildContext<CombinedValidator>,
     ) -> PyResult<CombinedValidator> {
         let py = schema.py();
 
@@ -48,7 +48,7 @@ impl BuildValidator for ArgumentsValidator {
         let mut had_default_arg = false;
 
         for (arg_index, arg) in arguments_schema.iter().enumerate() {
-            let arg: &PyDict = arg.cast_as()?;
+            let arg: &PyDict = arg.downcast()?;
 
             let name: String = arg.get_as_req(intern!(py, "name"))?;
             let mode = arg
@@ -304,7 +304,7 @@ impl Validator for ArgumentsValidator {
             }};
         }
         match args {
-            GenericArguments::Py(a) => process!(a, py_get_item, py_get, py_slice),
+            GenericArguments::Py(a) => process!(a, py_get_dict_item, py_get, py_slice),
             GenericArguments::Json(a) => process!(a, json_get, json_get, json_slice),
         }
         if !errors.is_empty() {
