@@ -3,7 +3,7 @@ use pyo3::intern;
 use pyo3::prelude::*;
 use pyo3::types::{PyAny, PyDict};
 
-use crate::build_tools::{function_name, kwargs, py_err, SchemaDict};
+use crate::build_tools::{function_name, py_err, SchemaDict};
 use crate::errors::{
     ErrorType, LocItem, PydanticCustomError, PydanticKnownError, PydanticOmit, ValError, ValResult, ValidationError,
 };
@@ -86,10 +86,10 @@ impl Validator for FunctionBeforeValidator {
         slots: &'data [CombinedValidator],
         recursion_guard: &'s mut RecursionGuard,
     ) -> ValResult<'data, PyObject> {
-        let kwargs = kwargs!(py, data: extra.data, config: self.config.clone_ref(py), context: extra.context);
+        let info = ValidationInfo::new(extra, &self.config, py);
         let value = self
             .func
-            .call(py, (input.to_object(py),), kwargs)
+            .call1(py, (input.to_object(py), info))
             .map_err(|e| convert_err(py, e, input))?;
 
         self.validator
@@ -129,8 +129,8 @@ impl Validator for FunctionAfterValidator {
         recursion_guard: &'s mut RecursionGuard,
     ) -> ValResult<'data, PyObject> {
         let v = self.validator.validate(py, input, extra, slots, recursion_guard)?;
-        let kwargs = kwargs!(py, data: extra.data, config: self.config.clone_ref(py), context: extra.context);
-        self.func.call(py, (v,), kwargs).map_err(|e| convert_err(py, e, input))
+        let info = ValidationInfo::new(extra, &self.config, py);
+        self.func.call1(py, (v, info)).map_err(|e| convert_err(py, e, input))
     }
 
     fn get_name(&self) -> &str {
@@ -178,9 +178,9 @@ impl Validator for FunctionPlainValidator {
         _slots: &'data [CombinedValidator],
         _recursion_guard: &'s mut RecursionGuard,
     ) -> ValResult<'data, PyObject> {
-        let kwargs = kwargs!(py, data: extra.data, config: self.config.clone_ref(py), context: extra.context);
+        let info = ValidationInfo::new(extra, &self.config, py);
         self.func
-            .call(py, (input.to_object(py),), kwargs)
+            .call1(py, (input.to_object(py), info))
             .map_err(|e| convert_err(py, e, input))
     }
 
@@ -208,18 +208,12 @@ impl Validator for FunctionWrapValidator {
         slots: &'data [CombinedValidator],
         recursion_guard: &'s mut RecursionGuard,
     ) -> ValResult<'data, PyObject> {
-        let validator_kwarg = ValidatorCallable {
+        let call_next_validator = ValidatorCallable {
             validator: InternalValidator::new(py, "ValidatorCallable", &self.validator, slots, extra, recursion_guard),
         };
-        let kwargs = kwargs!(
-            py,
-            validator: validator_kwarg,
-            data: extra.data,
-            config: self.config.clone_ref(py),
-            context: extra.context,
-        );
+        let info = ValidationInfo::new(extra, &self.config, py);
         self.func
-            .call(py, (input.to_object(py),), kwargs)
+            .call1(py, (input.to_object(py), call_next_validator, info))
             .map_err(|e| convert_err(py, e, input))
     }
 
@@ -303,3 +297,23 @@ pub fn convert_err<'a>(py: Python<'a>, err: PyErr, input: &'a impl Input<'a>) ->
         ValError::InternalErr(err)
     }
 }
+
+#[pyclass(module = "pydantic_core._pydantic_core")]
+pub struct ValidationInfo {
+    #[pyo3(get)]
+    data: Option<Py<PyDict>>,
+    #[pyo3(get)]
+    config: PyObject,
+    #[pyo3(get)]
+    context: Option<PyObject>,
+}
+
+impl ValidationInfo {
+    fn new(extra: &Extra, config: &PyObject, py: Python) -> Self {
+        ValidationInfo {
+            data: extra.data.map(|v| v.into()),
+            config: config.clone_ref(py),
+            context: extra.context.map(|v| v.into()),
+        }
+    }
+}
