@@ -1,16 +1,15 @@
 use pyo3::intern;
 use pyo3::prelude::*;
-#[cfg(not(PyPy))]
-use pyo3::types::PyFunction;
-use pyo3::types::{PyDict, PyList, PySet, PyString};
-#[cfg(not(PyPy))]
-use pyo3::PyTypeInfo;
 
 use ahash::AHashSet;
+use pyo3::types::{PyDict, PySet, PyString};
 
 use crate::build_tools::{is_strict, py_err, schema_or_config, schema_or_config_same, SchemaDict};
 use crate::errors::{py_err_string, ErrorType, ValError, ValLineError, ValResult};
-use crate::input::{GenericMapping, Input};
+use crate::input::{
+    AttributesGenericIterator, DictGenericIterator, GenericMapping, Input, JsonObjectGenericIterator,
+    MappingGenericIterator,
+};
 use crate::lookup_key::LookupKey;
 use crate::questions::Question;
 use crate::recursion_guard::RecursionGuard;
@@ -22,7 +21,7 @@ use super::{build_validator, BuildContext, BuildValidator, CombinedValidator, Ex
 struct TypedDictField {
     name: String,
     lookup_key: LookupKey,
-    name_pystring: Py<PyString>,
+    name_py: Py<PyString>,
     required: bool,
     validator: CombinedValidator,
     frozen: bool,
@@ -45,7 +44,7 @@ impl BuildValidator for TypedDictValidator {
     fn build(
         schema: &PyDict,
         config: Option<&PyDict>,
-        build_context: &mut BuildContext,
+        build_context: &mut BuildContext<CombinedValidator>,
     ) -> PyResult<CombinedValidator> {
         let py = schema.py();
         let strict = is_strict(schema, config)?;
@@ -88,7 +87,7 @@ impl BuildValidator for TypedDictValidator {
         let mut fields: Vec<TypedDictField> = Vec::with_capacity(fields_dict.len());
 
         for (key, value) in fields_dict.iter() {
-            let field_info: &PyDict = value.cast_as()?;
+            let field_info: &PyDict = value.downcast()?;
             let field_name: &str = key.extract()?;
 
             let schema = field_info.get_as_req(intern!(py, "schema"))?;
@@ -123,7 +122,7 @@ impl BuildValidator for TypedDictValidator {
                 }
             }
 
-            let lookup_key = match field_info.get_item(intern!(py, "alias")) {
+            let lookup_key = match field_info.get_item(intern!(py, "validation_alias")) {
                 Some(alias) => {
                     let alt_alias = if populate_by_name { Some(field_name) } else { None };
                     LookupKey::from_py(py, alias, alt_alias)?
@@ -134,7 +133,7 @@ impl BuildValidator for TypedDictValidator {
             fields.push(TypedDictField {
                 name: field_name.to_string(),
                 lookup_key,
-                name_pystring: PyString::intern(py, field_name).into(),
+                name_py: PyString::intern(py, field_name).into(),
                 validator,
                 required,
                 frozen: field_info.get_as::<bool>(intern!(py, "frozen"))?.unwrap_or(false),
@@ -192,9 +191,9 @@ impl Validator for TypedDictValidator {
         };
 
         macro_rules! process {
-            ($dict:ident, $get_method:ident, $iter_method:ident) => {{
+            ($dict:ident, $get_method:ident, $iter:ty $(,$kwargs:ident)?) => {{
                 for field in &self.fields {
-                    let op_key_value = match field.lookup_key.$get_method($dict) {
+                    let op_key_value = match field.lookup_key.$get_method($dict $(, $kwargs )? ) {
                         Ok(v) => v,
                         Err(err) => {
                             errors.push(ValLineError::new_with_loc(
@@ -218,9 +217,9 @@ impl Validator for TypedDictValidator {
                             .validate(py, value, &extra, slots, recursion_guard)
                         {
                             Ok(value) => {
-                                output_dict.set_item(&field.name_pystring, value)?;
+                                output_dict.set_item(&field.name_py, value)?;
                                 if let Some(ref mut fs) = fields_set_vec {
-                                    fs.push(field.name_pystring.clone_ref(py));
+                                    fs.push(field.name_py.clone_ref(py));
                                 }
                             }
                             Err(ValError::Omit) => continue,
@@ -233,7 +232,7 @@ impl Validator for TypedDictValidator {
                         }
                         continue;
                     } else if let Some(value) = get_default(py, &field.validator)? {
-                        output_dict.set_item(&field.name_pystring, value.as_ref())?;
+                        output_dict.set_item(&field.name_py, value.as_ref())?;
                     } else if field.required {
                         errors.push(ValLineError::new_with_loc(
                             ErrorType::Missing,
@@ -244,7 +243,8 @@ impl Validator for TypedDictValidator {
                 }
 
                 if let Some(ref mut used_keys) = used_keys {
-                    for (raw_key, value) in $dict.$iter_method() {
+                    for item_result in <$iter>::new($dict)? {
+                        let (raw_key, value) = item_result?;
                         let either_str = match raw_key.strict_str() {
                             Ok(k) => k,
                             Err(ValError::LineErrors(line_errors)) => {
@@ -302,9 +302,10 @@ impl Validator for TypedDictValidator {
             }};
         }
         match dict {
-            GenericMapping::PyDict(d) => process!(d, py_get_item, iter),
-            GenericMapping::PyGetAttr(d) => process!(d, py_get_attr, iter_attrs),
-            GenericMapping::JsonObject(d) => process!(d, json_get, iter),
+            GenericMapping::PyDict(d) => process!(d, py_get_dict_item, DictGenericIterator),
+            GenericMapping::PyGetAttr(d, kwargs) => process!(d, py_get_attr, AttributesGenericIterator, kwargs),
+            GenericMapping::PyMapping(d) => process!(d, py_get_mapping_item, MappingGenericIterator),
+            GenericMapping::JsonObject(d) => process!(d, json_get, JsonObjectGenericIterator),
         }
 
         if !errors.is_empty() {
@@ -327,7 +328,7 @@ impl Validator for TypedDictValidator {
         }
     }
 
-    fn complete(&mut self, build_context: &BuildContext) -> PyResult<()> {
+    fn complete(&mut self, build_context: &BuildContext<CombinedValidator>) -> PyResult<()> {
         self.fields
             .iter_mut()
             .try_for_each(|f| f.validator.complete(build_context))
@@ -399,71 +400,3 @@ impl TypedDictValidator {
         }
     }
 }
-
-trait IterAttributes<'a> {
-    fn iter_attrs(&self) -> AttributesIterator<'a>;
-}
-
-impl<'a> IterAttributes<'a> for &'a PyAny {
-    fn iter_attrs(&self) -> AttributesIterator<'a> {
-        AttributesIterator {
-            object: self,
-            attributes: self.dir(),
-            index: 0,
-        }
-    }
-}
-
-struct AttributesIterator<'a> {
-    object: &'a PyAny,
-    attributes: &'a PyList,
-    index: usize,
-}
-
-impl<'a> Iterator for AttributesIterator<'a> {
-    type Item = (&'a PyAny, &'a PyAny);
-
-    fn next(&mut self) -> Option<(&'a PyAny, &'a PyAny)> {
-        // loop until we find an attribute who's name does not start with underscore,
-        // or we get to the end of the list of attributes
-        loop {
-            if self.index < self.attributes.len() {
-                #[cfg(PyPy)]
-                let name: &PyAny = self.attributes.get_item(self.index).unwrap();
-                #[cfg(not(PyPy))]
-                let name: &PyAny = unsafe { self.attributes.get_item_unchecked(self.index) };
-                self.index += 1;
-                // from benchmarks this is 14x faster than using the python `startswith` method
-                let name_cow = name
-                    .cast_as::<PyString>()
-                    .expect("dir didn't return a PyString")
-                    .to_string_lossy();
-                if !name_cow.as_ref().starts_with('_') {
-                    // getattr is most likely to fail due to an exception in a @property, skip
-                    if let Ok(attr) = self.object.getattr(name_cow.as_ref()) {
-                        // we don't want bound methods to be included, is there a better way to check?
-                        // ref https://stackoverflow.com/a/18955425/949890
-                        let is_bound = matches!(attr.hasattr(intern!(attr.py(), "__self__")), Ok(true));
-                        // the PyFunction::is_type_of(attr) catches `staticmethod`, but also any other function,
-                        // I think that's better than including static methods in the yielded attributes,
-                        // if someone really wants fields, they can use an explicit field, or a function to modify input
-                        #[cfg(not(PyPy))]
-                        if !is_bound && !PyFunction::is_type_of(attr) {
-                            return Some((name, attr));
-                        }
-                        // MASSIVE HACK! PyFunction doesn't exist for PyPy,
-                        // is_instance_of::<PyFunction> crashes with a null pointer, hence this hack, see
-                        // https://github.com/pydantic/pydantic-core/pull/161#discussion_r917257635
-                        #[cfg(PyPy)]
-                        if !is_bound && attr.get_type().to_string() != "<class 'function'>" {
-                            return Some((name, attr));
-                        }
-                    }
-                }
-            } else {
-                return None;
-            }
-        }
-    }
-    // size_hint is omitted as it isn't needed
-}
