@@ -41,7 +41,7 @@ def test_on_model_class():
 
     v = SchemaValidator(
         {
-            'type': 'new-class',
+            'type': 'model',
             'cls': MyModel,
             'config': {'str_max_length': 5},
             'schema': {'type': 'typed-dict', 'return_fields_set': True, 'fields': {'f': {'schema': {'type': 'str'}}}},
@@ -55,7 +55,7 @@ def test_on_model_class():
 def test_field_priority_model():
     v = SchemaValidator(
         {
-            'type': 'new-class',
+            'type': 'model',
             'cls': MyModel,
             'config': {'str_max_length': 10},
             'schema': {
@@ -73,7 +73,7 @@ def test_field_priority_model():
 def test_parent_priority():
     v = SchemaValidator(
         {
-            'type': 'new-class',
+            'type': 'model',
             'cls': MyModel,
             'schema': {'type': 'typed-dict', 'return_fields_set': True, 'fields': {'f': {'schema': {'type': 'str'}}}},
             'config': {'str_min_length': 2, 'str_max_length': 10},
@@ -91,7 +91,7 @@ def test_parent_priority():
 def test_child_priority():
     v = SchemaValidator(
         {
-            'type': 'new-class',
+            'type': 'model',
             'cls': MyModel,
             'schema': {'type': 'typed-dict', 'return_fields_set': True, 'fields': {'f': {'schema': {'type': 'str'}}}},
             'config': {'str_max_length': 5, 'config_choose_priority': 1},
@@ -109,7 +109,7 @@ def test_child_priority():
 def test_merge_child_wins():
     v = SchemaValidator(
         {
-            'type': 'new-class',
+            'type': 'model',
             'cls': MyModel,
             'schema': {'type': 'typed-dict', 'return_fields_set': True, 'fields': {'f': {'schema': {'type': 'str'}}}},
             'config': {'str_max_length': 5},
@@ -127,7 +127,7 @@ def test_merge_child_wins():
 def test_merge_parent_wins():
     v = SchemaValidator(
         {
-            'type': 'new-class',
+            'type': 'model',
             'cls': MyModel,
             'schema': {'type': 'typed-dict', 'return_fields_set': True, 'fields': {'f': {'schema': {'type': 'str'}}}},
             'config': {'str_max_length': 5},
@@ -147,7 +147,7 @@ def test_merge_parent_wins():
 def test_sub_model_merge():
     v = SchemaValidator(
         {
-            'type': 'new-class',
+            'type': 'model',
             'cls': MyModel,
             'schema': {
                 'type': 'typed-dict',
@@ -156,7 +156,7 @@ def test_sub_model_merge():
                     'f': {'schema': {'type': 'str'}},
                     'sub_model': {
                         'schema': {
-                            'type': 'new-class',
+                            'type': 'model',
                             'cls': MyModel,
                             'schema': {
                                 'type': 'typed-dict',
@@ -230,7 +230,7 @@ def test_sub_model_merge():
 def test_allow_inf_nan(config: CoreConfig, float_field_schema, input_value, expected):
     v = SchemaValidator(
         {
-            'type': 'new-class',
+            'type': 'model',
             'cls': MyModel,
             'schema': {'type': 'typed-dict', 'fields': {'x': {'schema': float_field_schema}}},
             'config': config,
