@@ -1,3 +1,5 @@
+from enum import Enum
+
 import pytest
 
 from pydantic_core import SchemaError, SchemaValidator, ValidationError
@@ -80,6 +82,7 @@ def test_simple_tagged_union(py_and_json: PyAndJson, input_value, expected):
         {
             'type': 'tagged-union',
             'discriminator': 'foo',
+            'from_attributes': False,
             'choices': {
                 'apple': {
                     'type': 'typed-dict',
@@ -105,6 +108,119 @@ def test_simple_tagged_union(py_and_json: PyAndJson, input_value, expected):
         assert v.validate_test(input_value) == expected
 
 
+@pytest.mark.parametrize(
+    'input_value,expected',
+    [
+        ({'foo': 123, 'bar': '123'}, {'foo': 123, 'bar': 123}),
+        ({'foo': '123', 'bar': '123'}, {'foo': 123, 'bar': 123}),
+        ({'foo': 'banana', 'spam': [1, 2, '3']}, {'foo': 'banana', 'spam': [1, 2, 3]}),
+        (
+            {'foo': 123, 'bar': 'wrong'},
+            Err(
+                'Input should be a valid integer',
+                [
+                    {
+                        'type': 'int_parsing',
+                        'loc': (123, 'bar'),
+                        'msg': 'Input should be a valid integer, unable to parse string as an integer',
+                        'input': 'wrong',
+                    }
+                ],
+            ),
+        ),
+        (
+            {'foo': 1234567, 'bar': '123'},
+            Err(
+                'union_tag_invalid',
+                [
+                    {
+                        'type': 'union_tag_invalid',
+                        'loc': (),
+                        'msg': (
+                            "Input tag '1234567' found using 'foo' does not match any of the "
+                            "expected tags: 123, 'banana'"
+                        ),
+                        'input': {'foo': 1234567, 'bar': '123'},
+                        'ctx': {'discriminator': "'foo'", 'tag': '1234567', 'expected_tags': "123, 'banana'"},
+                    }
+                ],
+            ),
+        ),
+    ],
+)
+def test_int_choice_keys(py_and_json: PyAndJson, input_value, expected):
+    v = py_and_json(
+        {
+            'type': 'tagged-union',
+            'discriminator': 'foo',
+            'choices': {
+                123: {
+                    'type': 'typed-dict',
+                    'fields': {'foo': {'schema': {'type': 'int'}}, 'bar': {'schema': {'type': 'int'}}},
+                },
+                'banana': {
+                    'type': 'typed-dict',
+                    'fields': {
+                        'foo': {'schema': {'type': 'str'}},
+                        'spam': {'schema': {'type': 'list', 'items_schema': {'type': 'int'}}},
+                    },
+                },
+            },
+        }
+    )
+    assert 'discriminator: LookupKey' in repr(v.validator)
+    if isinstance(expected, Err):
+        with pytest.raises(ValidationError, match=expected.message) as exc_info:
+            v.validate_test(input_value)
+        # debug(exc_info.value.errors())
+        assert exc_info.value.errors() == expected.errors
+    else:
+        assert v.validate_test(input_value) == expected
+
+
+def test_enum_keys():
+    class FooEnum(str, Enum):
+        APPLE = 'apple'
+        BANANA = 'banana'
+
+    class BarEnum(int, Enum):
+        ONE = 1
+
+    v = SchemaValidator(
+        {
+            'type': 'tagged-union',
+            'discriminator': 'foo',
+            'choices': {
+                1: {
+                    'type': 'typed-dict',
+                    'fields': {'foo': {'schema': {'type': 'int'}}, 'bar': {'schema': {'type': 'int'}}},
+                },
+                'banana': {
+                    'type': 'typed-dict',
+                    'fields': {
+                        'foo': {'schema': {'type': 'str'}},
+                        'spam': {'schema': {'type': 'list', 'items_schema': {'type': 'int'}}},
+                    },
+                },
+            },
+        }
+    )
+
+    assert v.validate_python({'foo': FooEnum.BANANA, 'spam': [1, 2, '3']}) == {'foo': 'banana', 'spam': [1, 2, 3]}
+    assert v.validate_python({'foo': BarEnum.ONE, 'bar': '123'}) == {'foo': 1, 'bar': 123}
+    with pytest.raises(ValidationError) as exc_info:
+        v.validate_python({'foo': FooEnum.APPLE, 'spam': [1, 2, '3']})
+    assert exc_info.value.errors() == [
+        {
+            'type': 'union_tag_invalid',
+            'loc': (),
+            'msg': "Input tag 'apple' found using 'foo' does not match any of the expected tags: 1, 'banana'",
+            'input': {'foo': FooEnum.APPLE, 'spam': [1, 2, '3']},
+            'ctx': {'discriminator': "'foo'", 'tag': 'apple', 'expected_tags': "1, 'banana'"},
+        }
+    ]
+
+
 def test_discriminator_path(py_and_json: PyAndJson):
     v = py_and_json(
         {
@@ -258,7 +374,7 @@ def test_use_ref():
             'discriminator': 'foobar',
             'choices': {
                 'apple': {'type': 'typed-dict', 'ref': 'apple', 'fields': {'a': {'schema': {'type': 'str'}}}},
-                'apple2': {'type': 'recursive-ref', 'schema_ref': 'apple'},
+                'apple2': {'type': 'definition-ref', 'schema_ref': 'apple'},
                 'banana': {'type': 'typed-dict', 'fields': {'b': {'schema': {'type': 'str'}}}},
             },
         },
@@ -271,8 +387,16 @@ def test_use_ref():
 
 def test_downcast_error():
     v = SchemaValidator({'type': 'tagged-union', 'discriminator': lambda x: 123, 'choices': {'str': {'type': 'str'}}})
-    with pytest.raises(TypeError, match="'int' object cannot be converted to 'PyString'"):
+    with pytest.raises(ValidationError) as exc_info:
         v.validate_python('x')
+        assert exc_info.value.errors() == [
+            {
+                'type': 'union_tag_invalid',
+                'loc': (),
+                'msg': "Input tag '123' found using <lambda>() does not match any of the expected tags: 'str'",
+                'input': 'x',
+            }
+        ]
 
 
 def test_custom_error():
@@ -356,7 +480,40 @@ def test_custom_error_type():
     ]
 
 
-def test_tag_repeated(py_and_json: PyAndJson):
+@pytest.mark.parametrize(
+    'input_value,expected',
+    [
+        ({'food': 'apple', 'a': 'ap', 'b': '13'}, {'a': 'ap', 'b': 13}),
+        ({'food': 'durian', 'a': 'ap', 'b': '13'}, {'a': 'ap', 'b': 13}),
+        ({'food': 1, 'a': 123, 'b': '13'}, {'a': 123, 'b': 13}),
+        ({'food': 'banana', 'c': 'C', 'd': [1, '2']}, {'c': 'C', 'd': [1, 2]}),
+        ({'food': 'cherry', 'c': 'C', 'd': [1, '2']}, {'c': 'C', 'd': [1, 2]}),
+        ({'food': 2, 'a': 123, 'b': '13'}, {'a': 123, 'b': 13}),
+        (
+            {'food': 'wrong'},
+            Err(
+                'union_tag_invalid',
+                [
+                    {
+                        'type': 'union_tag_invalid',
+                        'loc': (),
+                        'msg': (
+                            "Input tag 'wrong' found using 'food' does not match any of the expected tags: "
+                            "'apple', 'banana', 1, 'cherry', 'durian', 2"
+                        ),
+                        'input': {'food': 'wrong'},
+                        'ctx': {
+                            'discriminator': "'food'",
+                            'tag': 'wrong',
+                            'expected_tags': "'apple', 'banana', 1, 'cherry', 'durian', 2",
+                        },
+                    }
+                ],
+            ),
+        ),
+    ],
+)
+def test_tag_repeated(py_and_json: PyAndJson, input_value, expected):
     v = py_and_json(
         {
             'type': 'tagged-union',
@@ -375,33 +532,23 @@ def test_tag_repeated(py_and_json: PyAndJson):
                 },
                 'cherry': 'banana',
                 'durian': 'apple',
+                1: {
+                    'type': 'typed-dict',
+                    'fields': {'a': {'schema': {'type': 'int'}}, 'b': {'schema': {'type': 'int'}}},
+                },
+                2: 1,
             },
         }
     )
-    assert v.validate_test({'food': 'apple', 'a': 'ap', 'b': '13'}) == {'a': 'ap', 'b': 13}
-    assert v.validate_test({'food': 'durian', 'a': 'ap', 'b': '13'}) == {'a': 'ap', 'b': 13}
+    if isinstance(expected, Err):
+        # insert_assert(exc_info.value.errors())
+        with pytest.raises(ValidationError, match=expected.message) as exc_info:
+            v.validate_test(input_value)
+        # debug(exc_info.value.errors())
+        assert exc_info.value.errors() == expected.errors
 
-    assert v.validate_test({'food': 'banana', 'c': 'C', 'd': [1, '2']}) == {'c': 'C', 'd': [1, 2]}
-    assert v.validate_test({'food': 'cherry', 'c': 'C', 'd': [1, '2']}) == {'c': 'C', 'd': [1, 2]}
-    with pytest.raises(ValidationError) as exc_info:
-        v.validate_test({'food': 'wrong'})
-    # insert_assert(exc_info.value.errors())
-    assert exc_info.value.errors() == [
-        {
-            'type': 'union_tag_invalid',
-            'loc': (),
-            'msg': (
-                "Input tag 'wrong' found using 'food' does not match any of the expected tags: "
-                "'apple', 'banana', 'cherry', 'durian'"
-            ),
-            'input': {'food': 'wrong'},
-            'ctx': {
-                'discriminator': "'food'",
-                'tag': 'wrong',
-                'expected_tags': "'apple', 'banana', 'cherry', 'durian'",
-            },
-        }
-    ]
+    else:
+        assert v.validate_test(input_value) == expected
 
 
 def test_tag_repeated_invalid():
